## Mission 
A test suite has a big effect on the maintainability and velocity of a project.

In this project, we strive for our tests to meet to following guidelines (based on https://abseil.io/resources/swe-book/html/ch12.html):

### Strive for unchanging tests.

### Test via public APIs.

### Test state, not interactions.

### Make your tests complete and concise.

### Test behaviors, not methods.

### Structure tests to emphasize behaviors.

### Name tests after the behavior being tested.

### Don’t put logic in tests.

### Write clear failure messages.

### Follow DAMP over DRY when sharing code for tests.